============
Musictheorpy
============

Musictheorpy is a Python library to perform musical calculations,
including intervals, triads/chords, and scales.

Read the Docs!
--------------

For the complete documentation, please visit `the docs <https://musictheorpy.readthedocs.io/en/latest/index.html>`_.

Installation
------------

Musictheorpy is free to use and modify under the MIT license. To install the package, simply run ``pip install musictheorpy``.
Note that while Musictheorpy might run in earlier versions, I am only officially supporting Python 3.6 and above.

Contributing
------------

Musictheorpy is under active development and will grow to include new features in the future. If you are interesting
contributing to the project, please see the Contributing page in the docs. Even if you don't want to contribute directly,
I am always open to hearing people's ideas, so if you have a thought on how the project can improve, please
feel free to send me an email at jeff.moorhead1@gmail.com with your name, thoughts on improving the library, and 
how I can best contact you to continue the discussion. I only ask that you be patient, as between work, graduate school,
and life, it may take me a few days to respond. Read more on contributing in `the full documentation <https://musictheorpy.readthedocs.io/en/latest/contributing.html>`_.
